/*
 * Copyright (c) 2008, Stefan Walter
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions of source code must retain the above
 *       copyright notice, this list of conditions and the
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the
 *       above copyright notice, this list of conditions and
 *       the following disclaimer in the documentation and/or
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be
 *       used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#ifndef PLUGIN_H_
#define PLUGIN_H_

#include <lber.h>
#include <ldap.h>

#ifdef HAVE_SLAPI_PLUGIN_H
#include <slapi-plugin.h>
#else
#include "include/slapi-plugin.h"
#endif

#define PLUGIN_NAME "slapi-dnsnotify"

/* ---------------------------------------------------------------------
 * LOGGING
 */

void log_msg (int level, const char* msg, ...);
void log_plugin (const char* msg, ...);

#define return_val_if_fail(expr, ret) \
	do { if (expr) { } else { \
		log_plugin ("*** %s *** check failed: '%s' at %s:%d", PLUGIN_NAME, #expr, __PRETTY_FUNCTION__, __LINE__); \
		return (ret); \
	} } while (0)
#define return_if_fail(expr) \
	do { if (expr) { } else { \
		log_plugin ("*** %s *** check failed: '%s' at %s:%d", PLUGIN_NAME, #expr, __PRETTY_FUNCTION__, __LINE__); \
		return; \
	} } while (0)

#if _DEBUG
void log_trace (const char *where, int line, const char *msg);
#define trace(x) log_trace (__PRETTY_FUNCTION__, __LINE__, (x))
#else
#define trace(x)
#endif

/* ----------------------------------------------------------------------
 * HELPERS
 */

const char* ltrim (const char *data);
void rtrim (char *data);
char* trim (char *data);
void lowercase (char *data);

/* ----------------------------------------------------------------------
 * AUTO SERIAL
 */

int autoserial_init (void);
void autoserial_destroy (void);
int autoserial_config (const char *name, const char *value);
void autoserial_post_add (const char *dn);
void autoserial_post_modify (const char *dn, LDAPMod **mods);
void autoserial_post_modrdn (const char *odn, const char *ndn);
void autoserial_post_delete (const char *dn);

/* ----------------------------------------------------------------------
 * DNS NOTIFY
 */

int dnsnotify_init (void);
void dnsnotify_destroy (void);
int dnsnotify_config (const char *name, const char *value);
void dnsnotify_post_add (const char *dn);
void dnsnotify_post_modify (const char *dn, LDAPMod **mods);


#endif /*PLUGIN_H_*/
