/*
 * Copyright (c) 2008, Stefan Walter
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions of source code must retain the above
 *       copyright notice, this list of conditions and the
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the
 *       above copyright notice, this list of conditions and
 *       the following disclaimer in the documentation and/or
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be
 *       used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 *
 * CONTRIBUTORS
 *  Stef Walter <stef@memberwebs.com>
 *
 */

#include "config.h"

#include "run-tests.h"

#include "common/strset.h"

#include <string.h>
#include <stdio.h>
#include <errno.h>

/*
 * Each test looks like (on one line):
 *     void unit_test_xxxxx (CuTest* cu)
 *
 * Each setup looks like (on one line):
 *     void unit_setup_xxxxx (void)
 *
 * Each teardown looks like (on one line):
 *     void unit_teardown_xxxxx (void)
 *
 * Tests be run in the order specified here.
 */

void unit_test_soa_strset (CuTest *cu)
{
	strset *set;
	int rc, i;
	char buf[32];

	set = strset_create ();
	CuAssertPtrNotNull (cu, set);

	CuAssert (cu, "found in empty set", !strset_has (set, "blah"));

	rc = strset_add (set, "blah");
	CuAssertIntEquals (cu, 0, rc);

	rc = strset_add (set, NULL);
	CuAssertIntEquals (cu, -1, rc);

	CuAssert (cu, "not found in set", strset_has (set, "blah"));

	/* Add some stuff so it forces us to reallocate */
	for (i = 0; i < 128; ++i) {
		snprintf (buf, sizeof (buf), "value-%d", i);
		strset_add (set, buf);
	}

	CuAssert (cu, "value-30 not found in set", strset_has (set, "value-30"));

	rc = strset_add (set, "");
	CuAssertIntEquals (cu, 0, rc);

	CuAssert (cu, "empty not found in set", strset_has (set, ""));

	rc = strset_remove (set, "blah");
	CuAssertIntEquals (cu, 0, rc);

	CuAssert (cu, "removed found in set", !strset_has (set, "blah"));

	strset_destroy (set);
}

/* -----------------------------------------------------------------------------
 * Code being tested
 */

#include "common/strset.c"
